pub struct VmProcedures { /* private fields */ }Implementations
Sourceimpl VmProcedures
impl VmProcedures
Sourcepub async fn restart_nonblocking(&self, vm_id: VmId) -> Result<(), RestartError>
pub async fn restart_nonblocking(&self, vm_id: VmId) -> Result<(), RestartError>
This function will try to initiate a soft restart of the VM The there is no guarantee that the VM has started once the returned future resolves
xo-cli: vm.restart id=
Sourcepub async fn snapshot(
&self,
vm_id: VmId,
name: String,
description: String,
save_memory: bool,
) -> Result<SnapshotId, RpcError>
pub async fn snapshot( &self, vm_id: VmId, name: String, description: String, save_memory: bool, ) -> Result<SnapshotId, RpcError>
Create snapshot of the specified VM
save_memory: Should the RAM memory of the VM be saved? Setting this to true does make the
snapshot take a lot more time, may even freeze the VM for some time. If you are unsure,
set this to false
xo-cli: vm.snapshot [description=
Sourcepub async fn revert(
&self,
snapshot_id: SnapshotId,
) -> Result<(), RevertSnapshotError>
pub async fn revert( &self, snapshot_id: SnapshotId, ) -> Result<(), RevertSnapshotError>
Roll back Vm to an earlier snapshot
xo-cli: vm.revert snapshot=