Subscription

Struct Subscription 

pub struct Subscription<Notif> { /* private fields */ }
Active subscription on the client.

It will automatically unsubscribe in the Subscription::drop so no need to explicitly call the unsubscribe method if it is an an subscription based on SubscriptionId.

Implementations

Source

impl<Notif> Subscription<Notif>

pub fn new( to_back: Sender<FrontToBack>, notifs_rx: Receiver<Value>, kind: SubscriptionKind, ) -> Subscription<Notif>

Create a new subscription.

Source

impl<Notif> Subscription<Notif>
where Notif: DeserializeOwned,

pub async fn next(&mut self) -> Result<Option<Notif>, Error>

Returns the next notification from the stream. This may return Ok(None) if the subscription has been terminated, may happen if the channel becomes full or is dropped.